==> r_assets-0.2.1.tar.gz: lib/generate_r_file/lib/mate/svg.dart <==
import 'dart:io';

import '../template_string.dart';

const _tCodeSvgAssetResource = """  /// asset: {#filePath#}
  // ignore: non_constant_identifier_names
  final {#varName#} = const AssetResource("{#filePath#}", packageName: R.package);
""";

const _tCodeSvg = """  /// asset: {#filePath#}
  // ignore: non_constant_identifier_names
  AssetSvg {#varName#}({@required double width, @required double height}) {
    final imageProvider = AssetSvg(asset.{#varName#}.keyName, width: width, height: height);
    return imageProvider;
  }
""";

//<editor-fold desc="转换svg类型">
MateSvg convertSvg(File file) {
  var res = MateSvg();
  res.assetFilePath = file.path;
  final tAsset = TemplateString(_tCodeSvgAssetResource);
  final tSvg = TemplateString(_tCodeSvg);
  res.generatedVarName = convertVarName(file.path);
  res.generatedCode4Asset = tAsset.format(<String, dynamic>{
    "filePath": file.path,
    'varName': res.generatedVarName,
  });
  res.generatedCode4Svg = tSvg.format(<String, dynamic>{
    "filePath": file.path,
    'varName': res.generatedVarName,
  });
  return res;
}

class MateSvg {
  String assetFilePath;
  String generatedVarName;
  String generatedCode4Asset;
  String generatedCode4Svg;

  @override
  String toString() {
    return 'MateImage{assetFilePath: $assetFilePath, generatedVarName: $generatedVarName}';
  }

  @override
  bool operator ==(Object other) {
    return other is MateSvg && other.generatedVarName == this.generatedVarName;
  }

  @override
  int get hashCode => generatedVarName.hashCode;
}
//</editor-fold>

==> r_assets-0.2.3.tar.gz: lib/generate_r_file/lib/mate/svg.dart <==
import 'dart:io';

import '../template_string.dart';

const _tCodeSvgAssetResource = """  /// asset: {#filePath#}
  // ignore: non_constant_identifier_names
  final {#varName#} = const AssetResource("{#filePath#}", packageName: R.package);
""";

const _tCodeSvg = """  /// asset: {#filePath#}
  // ignore: non_constant_identifier_names
  AssetSvg {#varName#}({required double width, required double height}) {
    final imageProvider = AssetSvg(asset.{#varName#}.keyName, width: width, height: height);
    return imageProvider;
  }
""";

//<editor-fold desc="转换svg类型">
MateSvg convertSvg(File file) {
  var res = MateSvg();
  res.assetFilePath = file.path;
  final tAsset = TemplateString(_tCodeSvgAssetResource);
  final tSvg = TemplateString(_tCodeSvg);
  res.generatedVarName = convertVarName(file.path);
  res.generatedCode4Asset = tAsset.format(<String, dynamic>{
    "filePath": file.path,
    'varName': res.generatedVarName,
  });
  res.generatedCode4Svg = tSvg.format(<String, dynamic>{
    "filePath": file.path,
    'varName': res.generatedVarName,
  });
  return res;
}

class MateSvg {
  String assetFilePath;
  String generatedVarName;
  String generatedCode4Asset;
  String generatedCode4Svg;

  @override
  String toString() {
    return 'MateImage{assetFilePath: $assetFilePath, generatedVarName: $generatedVarName}';
  }

  @override
  bool operator ==(Object other) {
    return other is MateSvg && other.generatedVarName == this.generatedVarName;
  }

  @override
  int get hashCode => generatedVarName.hashCode;
}
//</editor-fold>
